@@ -58,8 +58,11 @@ You'll eventually find one concrete predicate: :class:`yes`
 Predicates
 ----------
 .. autoclass:: Predicate
-.. autofunc:: objectify_predicate
+.. autofunction:: objectify_predicate
 .. autoclass:: yes
+.. autoclass:: AndPredicate
+.. autoclass:: OrPredicate
+.. autoclass:: NotPredicate
 
 Debugging
 ---------
@@ -78,6 +81,7 @@ from __future__ import print_function
 __docformat__ = "restructuredtext en"
 
 import sys
+import pkgutil
 import types
 import weakref
 import traceback as tb
@@ -91,6 +95,7 @@ from six import string_types, add_metaclass
 from logilab.common.modutils import modpath_from_file
 from logilab.common.logging_ext import set_log_methods
 from logilab.common.decorators import classproperty
+from logilab.common.deprecation import deprecated
 
 
 class RegistryException(Exception):
@@ -207,12 +212,22 @@ class RegistrableInstance(RegistrableObject):
         """Add a __module__ attribute telling the module where the instance was
         created, for automatic registration.
         """
+        module = kwargs.pop('__module__', None)
         obj = super(RegistrableInstance, cls).__new__(cls)
-        # XXX subclass must no override __new__
-        filepath = tb.extract_stack(limit=2)[0][0]
-        obj.__module__ = _modname_from_path(filepath)
+        if module is None:
+            warn('instantiate {0} with '
+                 '__module__=__name__'.format(cls.__name__),
+                 DeprecationWarning)
+            # XXX subclass must no override __new__
+            filepath = tb.extract_stack(limit=2)[0][0]
+            obj.__module__ = _modname_from_path(filepath)
+        else:
+            obj.__module__ = module
         return obj
 
+    def __init__(self, __module__=None):
+        super(RegistrableInstance, self).__init__()
+
 
 class Registry(dict):
     """The registry store a set of implementations associated to identifier:
@@ -237,15 +252,15 @@ class Registry(dict):
 
     Registration methods:
 
-    .. automethod: register
-    .. automethod: unregister
+    .. automethod:: register
+    .. automethod:: unregister
 
     Selection methods:
 
-    .. automethod: select
-    .. automethod: select_or_none
-    .. automethod: possible_objects
-    .. automethod: object_by_id
+    .. automethod:: select
+    .. automethod:: select_or_none
+    .. automethod:: possible_objects
+    .. automethod:: object_by_id
     """
     def __init__(self, debugmode):
         super(Registry, self).__init__()
@@ -483,11 +498,10 @@ class RegistryStore(dict):
     Controlling object registration
     -------------------------------
 
-    Dynamic loading is triggered by calling the
-    :meth:`register_objects` method, given a list of directories to
-    inspect for python modules.
+    Dynamic loading is triggered by calling the :meth:`register_modnames`
+    method, given a list of modules names to inspect.
 
-    .. automethod: register_objects
+    .. automethod:: register_modnames
 
     For each module, by default, all compatible objects are registered
     automatically. However if some objects come as replacement of
@@ -672,6 +686,7 @@ class RegistryStore(dict):
         self._loadedmods = {}
         return filemods
 
+    @deprecated('use register_modnames() instead')
     def register_objects(self, path, extrapath=None):
         """register all objects found walking down <path>"""
         # load views from each directory in the instance's path
@@ -681,6 +696,23 @@ class RegistryStore(dict):
             self.load_file(filepath, modname)
         self.initialization_completed()
 
+    def register_modnames(self, modnames):
+        """register all objects found in <modnames>"""
+        self.reset()
+        self._loadedmods = {}
+        self._toloadmods = {}
+        toload = []
+        for modname in modnames:
+            filepath = pkgutil.find_loader(modname).get_filename()
+            if filepath[-4:] in ('.pyc', '.pyo'):
+                # The source file *must* exists
+                filepath = filepath[:-1]
+            self._toloadmods[modname] = filepath
+            toload.append((filepath, modname))
+        for filepath, modname in toload:
+            self.load_file(filepath, modname)
+        self.initialization_completed()
+
     def initialization_completed(self):
         """call initialization_completed() on all known registries"""
         for reg in self.values():
@@ -734,6 +766,8 @@ class RegistryStore(dict):
         # module
         self._lastmodifs[filepath] = mdate
         # load the module
+        if sys.version_info < (3,) and not isinstance(modname, str):
+            modname = str(modname)
         module = __import__(modname, fromlist=modname.split('.')[:-1])
         self.load_module(module)
 
@@ -1112,8 +1146,6 @@ class yes(Predicate): # pylint: disable=C0103
 
 # deprecated stuff #############################################################
 
-from logilab.common.deprecation import deprecated
-
 @deprecated('[lgc 0.59] use Registry.objid class method instead')
 def classid(cls):
     return '%s.%s' % (cls.__module__, cls.__name__)
